@@ -1,4 +1,6 @@
 package POE::Filter::SimpleHTTP;
+our $VERSION = '0.091700';
+
 use 5.010;
 use Moose;
 extends('Exporter', 'Moose::Object');
@@ -20,7 +22,6 @@ use UNIVERSAL::isa;
 
 use bytes;
 
-our $VERSION = '0.01';
 our @EXPORT = qw/PFSH_CLIENT PFSH_SERVER/;
 our $DEBUG = 0;
 
@@ -181,6 +182,12 @@ has 'method' =>
     lazy => 1
 );
 
+sub clone()
+{
+    my ($self, %params) = @_;
+    return $self->meta->clone_object($self, %params);
+}
+
 sub isa()
 {
     my ($self, $arg) = (shift(@_), shift(@_));
@@ -632,6 +639,10 @@ $DB::single=1;
 
 POE::Filter::SimpleHTTP - A simple client/server suitable HTTP filter
 
+=head1 VERSION
+
+version 0.091700
+
 =head1 SYNOPSIS
 
 use POE::Filter::SimpleHTTP;
@@ -761,4 +772,4 @@ Licensed and distributed under the GPL.
 __PACKAGE__->meta->make_immutable();
 no Moose;
 
-1;
+1;
\ No newline at end of file
